@@ -1,7 +1,7 @@
 /*
  Copyright (c) 2008-2009 TrueCrypt Developers Association. All rights reserved.
 
- Governed by the TrueCrypt License 2.8 the full text of which is contained in
+ Governed by the TrueCrypt License 3.0 the full text of which is contained in
  the file License.txt included in TrueCrypt binary and source code distribution
  packages.
 */
@@ -11,7 +11,11 @@
 #ifdef TC_UNIX
 #include <wx/mimetype.h>
 #include <wx/sckipc.h>
+#include <fcntl.h>
 #include <signal.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 #include <sys/utsname.h>
 #include "Platform/Unix/Process.h"
 #endif
@@ -673,6 +677,9 @@ namespace TrueCrypt
 				catch (PasswordException&) { }
 			}
 
+			if (!options.Keyfiles && GetPreferences().UseKeyfiles && !GetPreferences().DefaultKeyfiles.empty())
+				options.Keyfiles = make_shared <KeyfileList> (GetPreferences().DefaultKeyfiles);
+
 			if ((options.Password && !options.Password->IsEmpty())
 				|| (options.Keyfiles && !options.Keyfiles->empty()))
 			{
@@ -799,8 +806,13 @@ namespace TrueCrypt
 			};
 #endif
 
+			wxLogLevel logLevel = wxLog::GetLogLevel();
+			wxLog::SetLogLevel (wxLOG_Error);
+
 			SingleInstanceChecker.reset (new wxSingleInstanceChecker (wxString (L".") + Application::GetName() + L"-lock-" + wxGetUserId()));
-			
+
+			wxLog::SetLogLevel (logLevel);
+
 			if (SingleInstanceChecker->IsAnotherRunning())
 			{
 #ifdef TC_WINDOWS
@@ -821,6 +833,31 @@ namespace TrueCrypt
 					return false;
 				}
 #endif
+
+#if defined(TC_UNIX) && !defined(TC_MACOSX)
+				try
+				{
+					int showFifo = open (string (MainFrame::GetShowRequestFifoPath()).c_str(), O_WRONLY | O_NONBLOCK);
+					throw_sys_if (showFifo == -1);
+
+					byte buf[1] = { 1 };
+					if (write (showFifo, buf, 1) == 1)
+					{
+						close (showFifo);
+						Application::SetExitCode (0);
+						return false;
+					}
+
+					close (showFifo);
+				}
+				catch (...)
+				{
+#ifdef DEBUG
+					throw;
+#endif
+				}
+#endif
+
 				wxLog::FlushActive();
 				Application::SetExitCode (1);
 				Gui->ShowInfo (_("TrueCrypt is already running."));
